adaptsmoFMRI-package: Adaptive Smoothing of FMRI Data
Description
This package contains R functions for estimating the blood
oxygenation level dependent (BOLD) effect by using functional
Magnetic Resonance Imaging (fMRI) data, based on
adaptive Gauss Markov random fields, for real as well as
simulated data. The implemented simulations make use of efficient
Markov Chain Monte Carlo methods.
Arguments
Details
Package:
adaptsmoFMRI
Type:
Package
Version:
1.1
Date:
2013-01-16
License:
GPL-2
References
A. Brezger, L. Fahrmeir, A. Hennerfeind
Adaptive Gaussian Markov random fields with applications in
human brain mapping, Applied Statistics, 56, Part 3,
pp. 327-345, 2007
V. J. Schmid, A. Thornton, B. Witcher
Working with the DICOM and NIfTI Data Standards in R,
Journal of Statistical Software, Volume 44, Issue 6. 2011