Rdocumentation
powered by
Learn R Programming
adaptsmoFMRI (version 1.1)
data_simfmri2COVAR: Simulated FMRI Data Set (for two covariates)
Description
The data set contains a synthetic spatiotemporal data set, hence a simulated data set. The data set is an array of dimension 20 x 20 x 180.
Arguments